﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Entity;
using System.Data.Entity.Infrastructure;
using System.Linq;
using System.Net;
using System.Net.Http;
using System.Web.Http;
using System.Web.Http.Description;
using IngredientApp.Models;

namespace IngredientApp.Controllers
{
    //   [RoutePrefix("api/ProductosApi")]
    public class ProductosApiController : ApiController
    {
        private IngredientApp_dbEntities db = new IngredientApp_dbEntities();

        // GET: api/ProductosApi
        public IQueryable<Producto> GetProducto()
        {
            return db.Producto;
        }


        // GET: api/ProductosApi
        [Route("api/ProductosApi/{count}")]
        public int GetTotalProducto()
        {
            return db.Producto.Count();
        }


        // GET: api/GetProducto
        [Route("api/ProductosApi/{from}")]
        //[Route("{from}")]
        //[ActionName("From")]
        public IQueryable<Producto> GetProductoFrom(int id)
        {
            return db.Producto.Where(prod => prod.id >id); ;
        }



        // GET: api/ProductosApi/5
        [ResponseType(typeof(Producto))]
        public IHttpActionResult GetProducto(string codigo)
        {
            Producto producto = db.Producto.Find(codigo);
            if (producto == null)
            {
                return NotFound();
            }

            return Ok(producto);
        }

        // PUT: api/ProductosApi/5
        [ResponseType(typeof(void))]
        public IHttpActionResult PutProducto(string codigo, Producto producto)
        {
            if (!ModelState.IsValid)
            {
                return BadRequest(ModelState);
            }

            if (codigo != producto.codigo)
            {
                return BadRequest();
            }

            db.Entry(producto).State = EntityState.Modified;

            try
            {
                db.SaveChanges();
            }
            catch (DbUpdateConcurrencyException)
            {
                if (!ProductoExists(codigo))
                {
                    return NotFound();
                }
                else
                {
                    throw;
                }
            }

            return StatusCode(HttpStatusCode.NoContent);
        }

        // POST: api/ProductosApi
        [ResponseType(typeof(Producto))]
        public IHttpActionResult PostProducto(Producto producto)
        {
            if (!ModelState.IsValid)
            {
                return BadRequest(ModelState);
            }

            if (ProductoExists(producto.codigo))
            {
                return CreatedAtRoute("DefaultApi", new { id = producto.codigo }, producto); 

            }
            else
            {
                db.Producto.Add(producto);

                try
                {
                    db.SaveChanges();
                }
                catch (DbUpdateException)
                {
                    if (ProductoExists(producto.codigo))
                    {
                        return Conflict();
                    }
                    else
                    {
                        throw;
                    }
                }


            }

            return CreatedAtRoute("DefaultApi", new { id = producto.codigo }, producto);
        }

        // DELETE: api/ProductosApi/5
        [ResponseType(typeof(Producto))]
        public IHttpActionResult DeleteProducto(string codigo)
        {
            Producto producto = db.Producto.Find(codigo);
            if (producto == null)
            {
                return NotFound();
            }

            db.Producto.Remove(producto);
            db.SaveChanges();

            return Ok(producto);
        }

        protected override void Dispose(bool disposing)
        {
            if (disposing)
            {
                db.Dispose();
            }
            base.Dispose(disposing);
        }

        private bool ProductoExists(string codigo)
        {
            return db.Producto.Count(e => e.codigo == codigo) > 0;
        }
    }
}